@@ -110,7 +110,8 @@ latex_pkg_list <- function() {
     "\\usepackage[normalem]{ulem}",
     "\\usepackage[normalem]{ulem}",
     "\\usepackage[utf8]{inputenc}",
-    "\\usepackage{makecell}"
+    "\\usepackage{makecell}",
+    "\\usepackage{xcolor}"
   ))
 }
 
